==> sra-sdk_2.8.2-5+dfsg.orig.tar.xz: sra-tools-2.8.2-5/tools/vdb-config/interactive.h <==
/*==============================================================================
*
*                            PUBLIC DOMAIN NOTICE
*               National Center for Biotechnology Information
*
*  This software/database is a "United States Government Work" under the
*  terms of the United States Copyright Act.  It was written as part of
*  the author's official duties as a United States Government employee and
*  thus cannot be copyrighted.  This software/database is freely available
*  to the public for use. The National Library of Medicine and the U.S.
*  Government have not placed any restriction on its use or reproduction.
*
*  Although all reasonable efforts have been taken to ensure the accuracy
*  and reliability of the software and data, the NLM and the U.S.
*  Government do not and cannot warrant the performance or results that
*  may be obtained by using this software or data. The NLM and the U.S.
*  Government disclaim all warranties, express or implied, including
*  warranties of performance, merchantability or fitness for any particular
*  purpose.
*
*  Please cite the author in any work or product based on this material.
*
* ===========================================================================
*
*/

#ifndef _h_interacive_
#define _h_interacive_

#include "vdb-config-model.hpp" // vdbconf_model

#ifndef _h_kfc_defs_
#include <kfc/defs.h>
#endif

#ifndef _h_vdb_config_model_
#include "vdb-config-model.hpp"
#endif

#ifdef __cplusplus
extern "C" {
#endif

    rc_t run_interactive ( vdbconf_model & model );

#ifdef __cplusplus
}
#endif

#endif /* _h_interacive_ */

==> sra-sdk_2.11.3+dfsg.orig.tar.xz: sra-tools-2.11.3/tools/vdb-config/interactive.h <==
/*==============================================================================
*
*                            PUBLIC DOMAIN NOTICE
*               National Center for Biotechnology Information
*
*  This software/database is a "United States Government Work" under the
*  terms of the United States Copyright Act.  It was written as part of
*  the author's official duties as a United States Government employee and
*  thus cannot be copyrighted.  This software/database is freely available
*  to the public for use. The National Library of Medicine and the U.S.
*  Government have not placed any restriction on its use or reproduction.
*
*  Although all reasonable efforts have been taken to ensure the accuracy
*  and reliability of the software and data, the NLM and the U.S.
*  Government do not and cannot warrant the performance or results that
*  may be obtained by using this software or data. The NLM and the U.S.
*  Government disclaim all warranties, express or implied, including
*  warranties of performance, merchantability or fitness for any particular
*  purpose.
*
*  Please cite the author in any work or product based on this material.
*
* ===========================================================================
*
*/

#ifndef _h_interacive_
#define _h_interacive_

#include "vdb-config-model.hpp" // vdbconf_model

#ifndef _h_kfc_defs_
#include <kfc/defs.h>
#endif

#ifndef _h_vdb_config_model_
#include "vdb-config-model.hpp"
#endif

#ifdef __cplusplus
extern "C" {
#endif

/* implemented in interactive.cpp */
rc_t run_interactive ( vdbconf_model & model );

/* implemented in interactive2.cpp */
rc_t run_interactive2 ( vdbconf_model & model );

#ifdef __cplusplus
}
#endif

#endif /* _h_interacive_ */
